@@ -55,6 +55,7 @@
 
 #include <ktexteditor/markinterface.h>
 #include <ktexteditor/movinginterface.h>
+#include <ktexteditor_version.h>
 
 #include "SelectTargetView.h"
 
@@ -69,16 +70,19 @@ static const QString NinjaPrefix = QStringLiteral("[ninja]");
 
 static QIcon messageIcon(KateBuildView::ErrorCategory severity)
 {
-#define RETURN_CACHED_ICON(name)                                                                                                                                                                                                               \
-    {                                                                                                                                                                                                                                          \
-        static QIcon icon(QIcon::fromTheme(QStringLiteral(name)));                                                                                                                                                                             \
-        return icon;                                                                                                                                                                                                                           \
+    // clang-format off
+#define RETURN_CACHED_ICON(name, fallbackname) \
+    { \
+        static QIcon icon(QIcon::fromTheme(QStringLiteral(name), \
+                                           QIcon::fromTheme(QStringLiteral(fallbackname)))); \
+        return icon; \
     }
+    // clang-format on
     switch (severity) {
     case KateBuildView::CategoryError:
-        RETURN_CACHED_ICON("dialog-error")
+        RETURN_CACHED_ICON("data-error", "dialog-error")
     case KateBuildView::CategoryWarning:
-        RETURN_CACHED_ICON("dialog-warning")
+        RETURN_CACHED_ICON("data-warning", "dialog-warning")
     default:
         break;
     }
@@ -122,7 +126,7 @@ KateBuildView::KateBuildView(KTextEditor::Plugin *plugin, KTextEditor::MainWindo
     // e.g. from icpc: "main.cpp(14): error: no suitable conversion function from "std::string" to "int" exists"
     , m_filenameDetectorIcpc(QStringLiteral("(([a-np-zA-Z]:[\\\\/])?[a-zA-Z0-9_\\.\\+\\-/\\\\]+\\.[a-zA-Z0-9]+)\\(([0-9]+)\\)(:.*)"))
     , m_filenameDetectorGccWorked(false)
-    , m_newDirDetector(QStringLiteral("make\\[.+\\]: .+ `.*'"))
+    , m_newDirDetector(QStringLiteral("make\\[.+\\]: .+ '(.*)'"))
 {
     KXMLGUIClient::setComponentName(QStringLiteral("katebuild"), i18n("Kate Build Plugin"));
     setXMLFile(QStringLiteral("ui.rc"));
@@ -457,6 +461,7 @@ void KateBuildView::addError(const QString &filename, const QString &line, const
     // visible text
     // remove path from visible file name
     QFileInfo file(filename);
+
     item->setText(0, file.fileName());
     item->setText(1, line);
     item->setText(2, message.trimmed());
@@ -505,7 +510,11 @@ void KateBuildView::clearMarks()
 
 void KateBuildView::addMarks(KTextEditor::Document *doc, bool mark)
 {
+#if KTEXTEDITOR_VERSION >= QT_VERSION_CHECK(5,69,0)
+    KTextEditor::MarkInterfaceV2 *iface = qobject_cast<KTextEditor::MarkInterfaceV2 *>(doc);
+#else
     KTextEditor::MarkInterface *iface = qobject_cast<KTextEditor::MarkInterface *>(doc);
+#endif
     KTextEditor::MovingInterface *miface = qobject_cast<KTextEditor::MovingInterface *>(doc);
     if (!iface || m_markedDocs.contains(doc))
         return;
@@ -522,7 +531,7 @@ void KateBuildView::addMarks(KTextEditor::Document *doc, bool mark)
 
         auto line = item->data(1, Qt::UserRole).toInt();
         if (mark) {
-            ErrorCategory category = (ErrorCategory)item->data(0, ErrorRole).toInt();
+            ErrorCategory category = static_cast<ErrorCategory>(item->data(0, ErrorRole).toInt());
             KTextEditor::MarkInterface::MarkTypes markType {};
 
             switch (category) {
@@ -541,8 +550,12 @@ void KateBuildView::addMarks(KTextEditor::Document *doc, bool mark)
             }
 
             if (markType) {
+#if KTEXTEDITOR_VERSION >= QT_VERSION_CHECK(5,69,0)
+                iface->setMarkIcon(markType, messageIcon(category));
+#else
                 const int ps = 32;
                 iface->setMarkPixmap(markType, messageIcon(category).pixmap(ps, ps));
+#endif
                 iface->addMark(line - 1, markType);
             }
             m_markedDocs.insert(doc, doc);
@@ -637,7 +650,7 @@ QUrl KateBuildView::docUrl()
 {
     KTextEditor::View *kv = m_win->activeView();
     if (!kv) {
-        qDebug() << "no KTextEditor::View" << endl;
+        qDebug() << "no KTextEditor::View";
         return QUrl();
     }
 
@@ -936,11 +949,11 @@ void KateBuildView::slotReadReadyStdOut()
         m_buildUi.plainTextEdit->appendPlainText(line);
         // qDebug() << line;
 
-        if (m_newDirDetector.match(line).hasMatch()) {
+        QRegularExpressionMatch match = m_newDirDetector.match(line);
+
+        if (match.hasMatch()) {
             // qDebug() << "Enter/Exit dir found";
-            int open = line.indexOf(QLatin1Char('`'));
-            int close = line.indexOf(QLatin1Char('\''));
-            QString newDir = line.mid(open + 1, close - open - 1);
+            QString newDir = match.captured(1);
             // qDebug () << "New dir = " << newDir;
 
             if ((m_make_dir_stack.size() > 1) && (m_make_dir_stack.top() == newDir)) {
