@@ -22,55 +22,8 @@
     SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
 
-/*
- * Some explanation here on server configuration JSON, pending such ending up
- * in real user level documentation ...
- *
- * The default configuration in JSON format is roughly as follows;
-{
-    "global":
-    {
-        "root": null,
-    },
-    "servers":
-    {
-        "Python":
-        {
-            "command": "python3 -m pyls --check-parent-process"
-        },
-        "C":
-        {
-            "command": "clangd -log=verbose --background-index"
-        },
-        "C++":
-        {
-            "use": "C++"
-        }
-    }
-}
- * (the "command" can be an array or a string, which is then split into array)
- *
- * From the above, the gist is presumably clear.  In addition, each server
- * entry object may also have an "initializationOptions" entry, which is passed
- * along to the server as part of the 'initialize' method.  A clangd-specific
- * HACK^Hfeature uses this to add "compilationDatabasePath".
- *
- * Various stages of override/merge are applied;
- * + user configuration (loaded from file) overrides (internal) default configuration
- * + "lspclient" entry in projectMap overrides the above
- * + the resulting "global" entry is used to supplement (not override) any server entry
- *
- * One server instance is used per (root, servertype) combination.
- * If "root" is not specified, it default to the $HOME directory.  If it is
- * specified as an absolute path, then it used as-is, otherwise it is relative
- * to the projectBase.  For any document, the resulting "root" then determines
- * whether or not a separate instance is needed. If so, the "root" is passed
- * as rootUri/rootPath.
- *
- * In general, it is recommended to leave root unspecified, as it is not that
- * important for a server (your mileage may vary though).  Fewer instances
- * are obviously more efficient, and they also have a 'wider' view than
- * the view of many separate instances.
+/* see plugins.docbook lspclient-configuration
+ * for client configuration documentation
  */
 
 #include "lspclientservermanager.h"
@@ -90,7 +43,10 @@
 #include <QJsonArray>
 #include <QJsonDocument>
 #include <QJsonObject>
+#include <QJsonParseError>
 #include <QRegularExpression>
+#include <QThread>
+#include <QTime>
 #include <QTimer>
 
 // helper to find a proper root dir for the given document & file name that indicate the root dir
@@ -157,10 +113,9 @@ struct RevisionGuard {
         : m_doc(doc)
         , m_movingInterface(qobject_cast<KTextEditor::MovingInterface *>(doc))
     {
-        if (m_movingInterface) {
-            m_revision = m_movingInterface->revision();
-            m_movingInterface->lockRevision(m_revision);
-        }
+        Q_ASSERT(m_movingInterface);
+        m_revision = m_movingInterface->revision();
+        m_movingInterface->lockRevision(m_revision);
     }
 
     // really only need/allow this one (out of 5)
@@ -240,6 +195,16 @@ class LSPClientServerManagerImpl : public LSPClientServerManager
 
     typedef LSPClientServerManagerImpl self_type;
 
+    struct ServerInfo {
+        QSharedPointer<LSPClientServer> server;
+        // config specified server url
+        QString url;
+        QTime started;
+        int failcount = 0;
+        // pending settings to be submitted
+        QJsonValue settings;
+    };
+
     struct DocumentInfo {
         QSharedPointer<LSPClientServer> server;
         KTextEditor::MovingInterface *movingInterface;
@@ -256,7 +221,7 @@ class LSPClientServerManagerImpl : public LSPClientServerManager
     // merged default and user config
     QJsonObject m_serverConfig;
     // root -> (mode -> server)
-    QMap<QUrl, QMap<QString, QSharedPointer<LSPClientServer>>> m_servers;
+    QMap<QUrl, QMap<QString, ServerInfo>> m_servers;
     QHash<KTextEditor::Document *, DocumentInfo> m_docs;
     bool m_incrementalSync = false;
 
@@ -291,15 +256,25 @@ public:
         QTimer t;
         connect(&t, &QTimer::timeout, &q, &QEventLoop::quit);
 
-        auto run = [&q, &t](int ms) {
-            t.setSingleShot(true);
-            t.start(ms);
-            q.exec();
-        };
+        /* some msleep are used below which is somewhat BAD as it blocks/hangs
+         * the mainloop, however there is not much alternative:
+         * + running an inner mainloop leads to event processing,
+         *   which could trigger an unexpected sequence of 'events'
+         *   such as (re)loading plugin that is currently still unloading
+         *   (consider scenario of fast-clicking enable/disable of LSP plugin)
+         * + could reduce or forego the sleep, but that increases chances
+         *   on an unclean shutdown of LSP server, which may or may not
+         *   be able to handle that properly (so let's try and be a polite
+         *   client and try to avoid that to some degree)
+         * So we are left with a minor sleep compromise ...
+         */
 
         int count = 0;
         for (const auto &el : m_servers) {
-            for (const auto &s : el) {
+            for (const auto &si : el) {
+                auto &s = si.server;
+                if (!s)
+                    continue;
                 disconnect(s.data(), nullptr, this, nullptr);
                 if (s->state() != LSPClientServer::State::None) {
                     auto handler = [&q, &count, s]() {
@@ -315,17 +290,20 @@ public:
                 }
             }
         }
-        run(500);
+        QThread::msleep(500);
 
         // stage 2 and 3
         count = 0;
         for (count = 0; count < 2; ++count) {
             for (const auto &el : m_servers) {
-                for (const auto &s : el) {
+                for (const auto &si : el) {
+                    auto &s = si.server;
+                    if (!s)
+                        continue;
                     s->stop(count == 0 ? 1 : -1, count == 0 ? -1 : 1);
                 }
             }
-            run(100);
+            QThread::msleep(100);
         }
     }
 
@@ -384,8 +362,8 @@ public:
         // find entry for server(s) and move out
         for (auto &m : m_servers) {
             for (auto it = m.begin(); it != m.end();) {
-                if (!server || it->data() == server) {
-                    servers.push_back(*it);
+                if (!server || it->server.data() == server) {
+                    servers.push_back(it->server);
                     it = m.erase(it);
                 } else {
                     ++it;
@@ -417,16 +395,8 @@ public:
 private:
     void showMessage(const QString &msg, KTextEditor::Message::MessageType level)
     {
-        KTextEditor::View *view = m_mainWindow->activeView();
-        if (!view || !view->document())
-            return;
-
-        auto kmsg = new KTextEditor::Message(xi18nc("@info", "<b>LSP Client:</b> %1", msg), level);
-        kmsg->setPosition(KTextEditor::Message::AboveView);
-        kmsg->setAutoHide(5000);
-        kmsg->setAutoHideMode(KTextEditor::Message::Immediate);
-        kmsg->setView(view);
-        view->document()->postMessage(kmsg);
+        // inform interested view(er) which will decide how/where to show
+        emit LSPClientServerManager::showMessage(level, msg);
     }
 
     // caller ensures that servers are no longer present in m_servers
@@ -474,12 +444,49 @@ private:
     void onStateChanged(LSPClientServer *server)
     {
         if (server->state() == LSPClientServer::State::Running) {
+            // send settings if pending
+            for (auto &m : m_servers) {
+                for (auto &si : m) {
+                    if (si.server.data() == server && !si.settings.isUndefined()) {
+                        server->didChangeConfiguration(si.settings);
+                    }
+                }
+            }
             // clear for normal operation
             emit serverChanged();
         } else if (server->state() == LSPClientServer::State::None) {
             // went down
-            showMessage(i18n("Server terminated unexpectedly: %1", server->cmdline().join(QLatin1Char(' '))), KTextEditor::Message::Warning);
-            restart(server);
+            // find server info to see how bad this is
+            // if this is an occasional termination/crash ... ok then
+            // if this happens quickly (bad/missing server, wrong cmdline/config), then no restart
+            QSharedPointer<LSPClientServer> sserver;
+            QString url;
+            bool retry = true;
+            for (auto &m : m_servers) {
+                for (auto &si : m) {
+                    if (si.server.data() == server) {
+                        url = si.url;
+                        if (si.started.secsTo(QTime::currentTime()) < 60) {
+                            ++si.failcount;
+                        }
+                        // clear the entry, which will be re-filled if needed
+                        // otherwise, leave it in place as a dead mark not to re-create one in _findServer
+                        if (si.failcount < 2) {
+                            std::swap(sserver, si.server);
+                        } else {
+                            sserver = si.server;
+                            retry = false;
+                        }
+                    }
+                }
+            }
+            auto action = retry ? i18n("Restarting") : i18n("NOT Restarting");
+            showMessage(i18n("Server terminated unexpectedly ... %1 [%2] [homepage: %3] ", action, server->cmdline().join(QLatin1Char(' ')), url), KTextEditor::Message::Warning);
+            if (sserver) {
+                // sserver might still be in m_servers
+                // but since it died already bringing it down will have no (ill) effect
+                restart({sserver});
+            }
         }
     }
 
@@ -494,7 +501,6 @@ private:
         const auto projectBase = QDir(projectView ? projectView->property("projectBaseDir").toString() : QString());
         const auto &projectMap = projectView ? projectView->property("projectMap").toMap() : QVariantMap();
 
-
         // merge with project specific
         auto projectConfig = QJsonDocument::fromVariant(projectMap).object().value(QStringLiteral("lspclient")).toObject();
         auto serverConfig = merge(m_serverConfig, projectConfig);
@@ -502,6 +508,8 @@ private:
         // locate server config
         QJsonValue config;
         QSet<QString> used;
+        // reduce langId
+        auto realLangId = langId;
         while (true) {
             qCInfo(LSPCLIENT) << "language id " << langId;
             used << langId;
@@ -561,7 +569,8 @@ private:
         }
 
         auto root = QUrl::fromLocalFile(rootpath);
-        auto server = m_servers.value(root).value(langId);
+        auto &serverinfo = m_servers[root][langId];
+        auto &server = serverinfo.server;
         if (!server) {
             QStringList cmdline;
 
@@ -580,12 +589,17 @@ private:
                 }
             }
             if (cmdline.length() > 0) {
-                server.reset(new LSPClientServer(cmdline, root, serverConfig.value(QStringLiteral("initializationOptions"))));
-                m_servers[root][langId] = server;
+                server.reset(new LSPClientServer(cmdline, root, realLangId, serverConfig.value(QStringLiteral("initializationOptions"))));
                 connect(server.data(), &LSPClientServer::stateChanged, this, &self_type::onStateChanged, Qt::UniqueConnection);
-                if (!server->start()) {
+                if (!server->start(m_plugin)) {
                     showMessage(i18n("Failed to start server: %1", cmdline.join(QLatin1Char(' '))), KTextEditor::Message::Error);
+                } else {
+                    showMessage(i18n("Started server %2: %1", cmdline.join(QLatin1Char(' ')), serverDescription(server.data())), KTextEditor::Message::Positive);
                 }
+                serverinfo.settings = serverConfig.value(QStringLiteral("settings"));
+                serverinfo.started = QTime::currentTime();
+                serverinfo.url = serverConfig.value(QStringLiteral("url")).toString();
+                // leave failcount as-is
             }
         }
         return (server && server->state() == LSPClientServer::State::Running) ? server : nullptr;
@@ -599,17 +613,24 @@ private:
         Q_ASSERT(defaultConfigFile.isOpen());
         m_serverConfig = QJsonDocument::fromJson(defaultConfigFile.readAll()).object();
 
-        // consider specified configuration
-        const auto &configPath = m_plugin->m_configPath.path();
-        if (!configPath.isEmpty()) {
+        // consider specified configuration if existing
+        const auto configPath = m_plugin->configPath().toLocalFile();
+        if (!configPath.isEmpty() && QFile::exists(configPath)) {
             QFile f(configPath);
             if (f.open(QIODevice::ReadOnly)) {
-                auto data = f.readAll();
-                auto json = QJsonDocument::fromJson(data);
-                if (json.isObject()) {
-                    m_serverConfig = merge(m_serverConfig, json.object());
-                } else {
-                    showMessage(i18n("Failed to parse server configuration: %1", configPath), KTextEditor::Message::Error);
+                const auto data = f.readAll();
+                if (!data.isEmpty()) {
+                    QJsonParseError error;
+                    auto json = QJsonDocument::fromJson(data, &error);
+                    if (error.error == QJsonParseError::NoError) {
+                        if (json.isObject()) {
+                            m_serverConfig = merge(m_serverConfig, json.object());
+                        } else {
+                            showMessage(i18n("Failed to parse server configuration '%1': no JSON object", configPath), KTextEditor::Message::Error);
+                        }
+                    } else {
+                        showMessage(i18n("Failed to parse server configuration '%1': %2", configPath, error.errorString()), KTextEditor::Message::Error);
+                    }
                 }
             } else {
                 showMessage(i18n("Failed to read server configuration: %1", configPath), KTextEditor::Message::Error);
@@ -696,11 +717,8 @@ private:
     {
         auto doc = it.key();
         if (it != m_docs.end() && it->server) {
-            if (it->movingInterface) {
-                it->version = it->movingInterface->revision();
-            } else if (it->modified) {
-                ++it->version;
-            }
+            it->version = it->movingInterface->revision();
+
             if (!m_incrementalSync) {
                 it->changes.clear();
             }
