@@ -1,22 +1,22 @@
-/*   This file is part of the KDE project
- *
- *   Copyright (C) 2014 Dominik Haumann <dhauumann@kde.org>
- *
- *   This library is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU Library General Public
- *   License as published by the Free Software Foundation; either
- *   version 2 of the License, or (at your option) any later version.
- *
- *   This library is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *   Library General Public License for more details.
- *
- *   You should have received a copy of the GNU Library General Public License
- *   along with this library; see the file COPYING.LIB.  If not, write to
- *   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *   Boston, MA 02110-1301, USA.
- */
+/*  SPDX-License-Identifier: LGPL-2.0-or-later
+
+    Copyright (C) 2014 Dominik Haumann <dhaumann@kde.org>
+
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
+
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
+*/
 
 #include "katetabbutton.h"
 
@@ -50,9 +50,8 @@ TabCloseButton::TabCloseButton(QWidget *parent)
 void TabCloseButton::paintEvent(QPaintEvent *)
 {
     // get the tab this close button belongs to
-    KateTabButton *tabButton = qobject_cast<KateTabButton*>(parent());
-    const bool isActive = underMouse()
-        || (tabButton && tabButton->isChecked());
+    KateTabButton *tabButton = qobject_cast<KateTabButton *>(parent());
+    const bool isActive = underMouse() || (tabButton && tabButton->isChecked());
 
     QStyleOptionButton opt;
     opt.initFrom(this);
@@ -90,7 +89,6 @@ void TabCloseButton::leaveEvent(QEvent *event)
     QPushButton::leaveEvent(event);
 }
 
-
 KateTabButton::KateTabButton(const QString &text, QWidget *parent)
     : QAbstractButton(parent)
     , m_geometryAnimation(nullptr)
@@ -103,7 +101,7 @@ KateTabButton::KateTabButton(const QString &text, QWidget *parent)
     // add close button
     const int margin = style()->pixelMetric(QStyle::PM_ButtonMargin, nullptr, this);
     m_closeButton = new TabCloseButton(this);
-    QHBoxLayout * hbox = new QHBoxLayout(this);
+    QHBoxLayout *hbox = new QHBoxLayout(this);
     hbox->setSpacing(0);
     hbox->setContentsMargins(margin, 0, margin, 0);
     hbox->addStretch();
@@ -151,7 +149,7 @@ void KateTabButton::paintEvent(QPaintEvent *ev)
 
     // icon, if applicable
     int leftMargin = margin;
-    if (! icon().isNull()) {
+    if (!icon().isNull()) {
         const int y = (height() - 16) / 2;
         icon().paint(&p, margin, y, 16, 16);
         leftMargin += 16;
@@ -159,9 +157,9 @@ void KateTabButton::paintEvent(QPaintEvent *ev)
     }
 
     // the width of the text is reduced by the close button + 2 * margin
-    const int w = width() // width of widget
-                - m_closeButton->width() - 2 * margin // close button
-                - leftMargin; // modified button
+    const int w = width()                     // width of widget
+        - m_closeButton->width() - 2 * margin // close button
+        - leftMargin;                         // modified button
 
     // draw text, we need to elide to xxx...xxx is too long
     const QString elidedText = QFontMetrics(font()).elidedText(text(), Qt::ElideMiddle, w);
@@ -182,7 +180,7 @@ void KateTabButton::mousePressEvent(QMouseEvent *ev)
 
     // activation code
     if (ev->button() == Qt::LeftButton) {
-        if (! isChecked()) {
+        if (!isChecked()) {
             // make sure we stay checked
             setChecked(true);
         }
@@ -199,8 +197,7 @@ void KateTabButton::mousePressEvent(QMouseEvent *ev)
 void KateTabButton::mouseMoveEvent(QMouseEvent *event)
 {
     // possibly start drag event
-    if (QPoint(event->globalPos() - m_mouseDownPosition).manhattanLength() > QApplication::startDragDistance())
-    {
+    if (QPoint(event->globalPos() - m_mouseDownPosition).manhattanLength() > QApplication::startDragDistance()) {
         QMimeData *mimeData = new QMimeData;
         mimeData->setData(QStringLiteral("application/x-dndkatetabbutton"), QByteArray());
         mimeData->setUrls({m_url});
@@ -208,7 +205,7 @@ void KateTabButton::mouseMoveEvent(QMouseEvent *event)
         auto drag = new QDrag(this);
         drag->setMimeData(mimeData);
         drag->setDragCursor(QPixmap(), Qt::MoveAction);
-        drag->start(Qt::MoveAction);
+        drag->exec(Qt::MoveAction);
         event->accept();
     }
     QAbstractButton::mouseMoveEvent(event);
@@ -254,12 +251,10 @@ bool KateTabButton::isActiveTabBar() const
     return parentWidget()->property("isActive").toBool();
 }
 
-void KateTabButton::setAnimatedGeometry(const QRect & startGeom,
-                                        const QRect & endGeom)
+void KateTabButton::setAnimatedGeometry(const QRect &startGeom, const QRect &endGeom)
 {
     // stop animation in case it is running
-    if (m_geometryAnimation &&
-        m_geometryAnimation->state() != QAbstractAnimation::Stopped) {
+    if (m_geometryAnimation && m_geometryAnimation->state() != QAbstractAnimation::Stopped) {
         m_geometryAnimation->stop();
     }
 
@@ -269,14 +264,12 @@ void KateTabButton::setAnimatedGeometry(const QRect & startGeom,
     }
 
     // if the style does not want animations, just set geometry
-    if (! style()->styleHint(QStyle::SH_Widget_Animate, nullptr, this)
-        || (isVisible() && endGeom == startGeom))
-    {
+    if (!style()->styleHint(QStyle::SH_Widget_Animate, nullptr, this) || (isVisible() && endGeom == startGeom)) {
         setGeometry(endGeom);
         return;
     }
 
-    if (! m_geometryAnimation) {
+    if (!m_geometryAnimation) {
         m_geometryAnimation = new QPropertyAnimation(this, "geometry", this);
         m_geometryAnimation->setDuration(100);
     }
@@ -289,8 +282,7 @@ void KateTabButton::setAnimatedGeometry(const QRect & startGeom,
 
 bool KateTabButton::geometryAnimationRunning() const
 {
-    return m_geometryAnimation
-        && (m_geometryAnimation->state() != QAbstractAnimation::Stopped);
+    return m_geometryAnimation && (m_geometryAnimation->state() != QAbstractAnimation::Stopped);
 }
 
 QUrl KateTabButton::url() const
